Skateparks.API = {
	endpoint : 'http://api.skateparks.co/',
	format : 'json',
	methods : ['GET', 'POST', 'PUT', 'DELETE']
};

/*
 *
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.API.createXHR = function(params) {
	
	_.extend(params, {
		onComplete : function() {},
		onError : function() {}
	});

	var xhr = Ti.Network.createHTTPClient({
		onload : params.onComplete,
		onerror : params.onError
	});
	
	return xhr;
	
};

/*
 * Determines of a given method is valid. 
 * 
 * @example GET => true, FOO => false
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.API.isValidMethod = function(method) {
	return (_.indexOf(Skateparks.API.methods, method) !== -1);
};

/*
 *
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.API.createClient = function(options) {
	
	var client = {
		format : options.format || Skateparks.API.format,
		method : 'GET',
		api : options.api || null,
		url : '',
		xhr : null,
		params : options.params || {},
		endpoint : options.endpoint || Skateparks.API.endpoint
	};
	
	// Method
	var method = options.method;
	if (method && Skateparks.API.isValidMethod(method)) {
		client.method = method;
	}
	
	client.url = Skateparks.API.createURL(options);	
	client.xhr = Skateparks.API.createXHR(options);

	client.execute =  function () {
		// TODO: Add support for methods other than GET
		this.xhr.open(this.method, this.url);
		this.xhr.send();
	};
	
	return client;

};

/*
 * Creates the full URL based on the api/method/params. If the method is GET
 * then the params will be appended onto the URL.
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.API.createURL = function(options) {
	var url = this.endpoint + this.api + '.' + this.format;
	if (this.method == "GET") {
		var query = Skateparks.API.createQueryString(this.params);
		if (query.length > 0) {
			url = url + '?' + query;
		}
	}
	return url;
};

/*
 * Takes an array of keys and values and returns a query string to be
 * used in a URL. Example: { foo => 'bar', 'boo' => 'zip' } => foo=bar&boo=zip
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.API.createQueryString = function(params) {
	var queryArray = [];
	_.each(params, function(value, key) {
		value = (null !== value) ? encodeURIComponent(value) : '';
		queryArray.push(key + '=' + value);
	});
	var queryString = queryArray.join('&');
	return queryString;
};
