Skateparks.Map = {};

/*
 *
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.calculateRegion = function(skateparks) {

	var minlat = 90.0;
	var maxlat = -90.0;
	var minlng = 180.0;
	var maxlng = -180.0;
	
	_.each(skateparks, function(skatepark) {
		minlat = Math.min(skatepark.latitude, minlat);
    	maxlat = Math.max(skatepark.latitude, maxlat);
    	minlng = Math.min(skatepark.longitude, minlng);
    	maxlng = Math.max(skatepark.longitude, maxlng);		
	});
	
	var region = Skateparks.Map.createRegion(minlat, maxlat, minlng, maxlng);
	
	return region;
	
};

/*
 *
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.createRegion = function(mixlat, maxlat, minlng, maxlng) {
	
	var latitude = (minlat + maxlat) / 2.0;
	var longitude = (minlng + maxlng) / 2.0;
	var latitudeDelta = Skateparks.Map.createDelta(minlat, maxlat); 
	var longitudeDelta = Skateparks.Map.createDelta(minlng, maxlng);

	var region = {
		latitude : latitude, 
		longitude : longitude, 
		latitudeDelta : latitudeDelta,
		longitudeDelta : longitudeDelta
	};
	
	return region;

};

/*
 * 
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.createDelta = function(min, max) {
	var minimumDelta = 0.0175;
	var calculatedDelta = max - min;
	return Math.max(minimumDelta, calculatedDelta);
};

/*
 * 
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.defaultOptions = function() {
	return {
		mapType: Titanium.Map.STANDARD_TYPE,
		region : Skateparks.Map.defaultRegion(),
		visible : true,
		regionFit:true
	}
};

/*
 * 
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.defaultRegion = function() {
	var region = {
		latitude : 33.74511, 
		longitude : -84.38993, 
		latitudeDelta : 0.5,
		longitudeDelta : 0.5
	};
	return region;
};

/*
 * 
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.createAnnotation = function(_args) {
	
	var skatepark = _args['skatepark'];
	
	/*btn = Ti.UI.createButton({
		style : Titanium.UI.iPhone.SystemButton.DISCLOSURE
	});*/
	
	var annotation = Ti.Map.createAnnotation({
		latitude : skatepark.latitude,
		longitude : skatepark.longitude,
		title : skatepark.name,
		rightButton: Titanium.UI.iPhone.SystemButton.DISCLOSURE,
		subtitle : skatepark.street + ', ' + skatepark.locality + ', ' + skatepark.region + ' ' + skatepark.postal_code
	});
	
	annotation.addEventListener('click', function(e) {
		if(e.clicksource == "rightButton") {
			detail = Skateparks.UI.createSkateparkWindow({
				title : skatepark.name,
				skatepark_id : skatepark.id
			});
			Skateparks.tabgroup.activeTab.open(detail);
		}
	});
	
	return annotation;
	
};

/*
 *
 *
 * @author Kyle Decot <kyle.decot@me.com> January 01 2012
 */

Skateparks.Map.createView = function(_args) {
	
	var map = Titanium.Map.createView(_args);
	
	map.addSkateparks = function(skateparks) {
		// TODO: DON'T remove the user location annotation (if possible)
		_.each(skateparks, function(skatepark) {
			var annotation = Skateparks.Map.createAnnotation({ skatepark : skatepark });
			map.addAnnotation(annotation);
		});
		var region = Skateparks.Map.calculateRegion(skateparks);
		map.setRegion(region);	
	};

	return map;
};
